package com.chinaitop.receive.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaitop.receive.model.ReceiveData;
import com.chinaitop.receive.mapper.ReceiveDataMapper;
import com.chinaitop.token.GetTokenConfig;
import com.chinaitop.utils.FilePullUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author qingsong.han
 * @description: 事件推送接收接口文档-505页(事件告警类型-725页)
 * @create 2023-09-18 16:08
 */

public interface ReceiveMessagesService extends IService<ReceiveData> {

    // 接收,解析异常消息保存
    void saveMessage(ReceiveData receive) throws Exception;

    @Slf4j
    @Service
    class ReceiveMessagesImpl extends ServiceImpl<ReceiveDataMapper, ReceiveData> implements ReceiveMessagesService {
        @Resource
        private ReceiveDataMapper dataMapper;
        @Resource
        private GetTokenConfig config;
        @Resource
        private FilePullUtil filePullUtil;
        @Value("${videoRootPath}")
        private String serverPath;

        @Override
        public void saveMessage(ReceiveData receive) throws Exception {
            /*图片路径转换返回示例
            {
               "error_code": "0000000000",
               "message": "操作成功",
               "data": ["http://10.69.15.150:11125/nginx-proxy?image_url=http://10.69.15.150:9003/?videolabel/dn@0_0/1/4-17951b2a-443ba"]
            }
            */
            // 图片路径转换
            String[] picture_url = {receive.getPicture_url()};
            List imageUrl = (List) config.getImageUrl(picture_url).get("data");
            // 下载图片到本地
            String sUrl = imageUrl.get(0).toString();
            // 图片
            String imageName = String.format("%s%s", receive.getId(), ".png");
            filePullUtil.pictureFile(sUrl, imageName);
            // 保存数据
            receive.setImage_url(imageName);
            dataMapper.insert(receive);

            /*int insert = dataMapper.insert(receive);
            if (insert > 0) {
                // 拉去图片,视频流(开启新线程) TODO
                String picture_url = receive.getPicture_url();
                // 判断图片是否是云存(/file/mg/开头的,则表示是非云存图片,否则则是云存图片)文档77页
                if (picture_url.startsWith("/file/mg/")) {
                    // 非云存图片,直接在图片相对路径前拼接http://平台 IP:14178
                } else {
                    // 云存储图片(调用图片路径转换(文档523页)接口获取绝对路径)
                }
            }*/
        }

    }
}
