package com.chinaitop.subscribe.controller;

import com.chinaitop.token.GetTokenConfig;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.Map;

/**
 * @author qingsong.han
 * @description: 设置订阅配置
 * @create 2023-09-15 16:51
 */
@Slf4j
@RestController
@RequestMapping("/subscribe")
public class SubscribeMessageController {
    @Resource
    private GetTokenConfig config;

    /**
     * {
     * "mode": 0,
     * "event_type_list": ["01066666","01067777","01068888"],
     * "accept_url": "http://101.36.160.140:21024/receive/messages"
     * }
     * mode: 事件推送模式
     * 单向推送模式(0): 事件中心不关注此推送请求的响应，默认事件已送达
     * 异步推送模式(1): 事件中心不关注此推送请求的响应，事件送达确认需要
     * 根据回调确认，长时间未回调会进行重复推送
     * 同步推送模式(2): 事件中心会根据推送请求的响应状态码来确认是否成
     * 功推送，如果失败则会进行重复推送
     * Kafka推送模式(3): 无
     * <p>
     * accept_url:
     * 事件接收地址:
     * 1、mode 为 0/1/2 时，接收方接收数据的 URL，该地址能
     * 接收的推送请求;
     * 2、mode为3时，格式为“${kafka地址}@${topic}”，kafka
     * 地址英文“,”号分隔
     * <p>
     * event_type_list: 事件类型编码
     *
     * @param subscribe 订阅参数
     */
    @PostMapping("/messages")
    public Map receiveMessages(@RequestBody Map<String, Object> subscribe) {
        return config.subscribeAlarm(subscribe);
    }

}
