package com.chinaitop.token;

import com.chinaitop.utils.RedisUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.*;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * @author qingsong.han
 * @description: 获取重庆紫光华山智安科技有限公司token
 * @create 2023-09-15 11:48
 */
@Slf4j
@Component
public class GetTokenConfig {
    @Resource
    private RedisUtil redisUtil;
    @Resource
    private RestTemplate restTemplate;
    // token
    @Value("${token.url}")
    private String url;
    @Value("${token.userId}")
    private String client_id;
    @Value("${token.password}")
    private String client_secret;
    // subscribe
    @Value("${subscribe.url}")
    private String sbUrl;
    @Value("${imageUrl}")
    private String imageUrl;

    // 获取token
    public void getToken() {
        String reqParam = "?grant_type={grant_type}&client_id={client_id}&client_secret={client_secret}&format={format}";
        Map<String, Object> paramMap = new HashMap<>();
        paramMap.put("client_id", client_id);
        paramMap.put("client_secret", client_secret);
        paramMap.put("grant_type", "client_credentials");
        paramMap.put("format", "json");
        Map forObject = restTemplate.getForObject(String.format("%s%s", url, reqParam), Map.class, paramMap);
        // 缓存到redis设置过期时间5400s(第三方token为2小时需要设置为1.5小时(5400s)防止过期)
        redisUtil.set("access_token", forObject.get("access_token").toString(), 5400);
        redisUtil.set("refresh_token", forObject.get("refresh_token").toString(), 27900);
        log.info("getTokenResponse:{}", forObject);
    }

    // 刷新token有效期8小时设置为7.5小时(27900s)
    public void refreshToken() {
        // refresh_token是否过期
        if (redisUtil.hasKey("refresh_token")) {
            String reqParam = "?grant_type={grant_type}&client_id={client_id}&client_secret={client_secret}&refresh_token={refresh_token}&format={format}";
            String refresh_token = redisUtil.get("refresh_token").toString();
            Map<String, Object> paramMap = new HashMap<>();
            paramMap.put("grant_type", "refresh_token");
            paramMap.put("client_id", client_id);
            paramMap.put("client_secret", client_secret);
            paramMap.put("refresh_token", refresh_token);
            paramMap.put("format", "json");
            Map forObject = restTemplate.getForObject(String.format("%s%s", url, reqParam), Map.class, paramMap);
            // 更新缓存
            redisUtil.set("access_token", forObject.get("access_token").toString(), 5400);
            log.info("refreshTokenResponse:{}", forObject);
        } else {
            // 重新获取token
            this.getToken();
        }
    }

    // 订阅(post)
    @SuppressWarnings("all")
    public Map subscribeAlarm(Map<String, Object> subscribe) {
        log.info("subscribeMessages------------:{}", subscribe);
        HttpEntity<Object> entity = this.addHeader(subscribe);
        ResponseEntity<Map> response = restTemplate.exchange(sbUrl, HttpMethod.POST, entity, Map.class);
        return response.getBody();
    }

    // 图片路径转换
    public Map getImageUrl(String[] pictureUrl) {
        // 添加header
        HttpEntity<Object> entity = this.addHeader(pictureUrl);
        ResponseEntity<Map> response = restTemplate.exchange(imageUrl, HttpMethod.POST, entity, Map.class);
        return response.getBody();
    }

    public HttpEntity<Object> addHeader(Map<String, Object> requestBody) {
        return new HttpEntity<>(requestBody, this.headers());
    }

    public HttpEntity<Object> addHeader(String[] requestBody) {
        return new HttpEntity<>(requestBody, this.headers());
    }

    public HttpHeaders headers() {
        // 添加header
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type", "application/json");
        headers.add("User", "usercode:" + client_id);
        headers.add("Cookie", "usercode=" + client_id);
        if (redisUtil.hasKey("access_token")) {
            headers.add("Authorization", redisUtil.get("access_token").toString());
        }
        return headers;
    }

}
