package com.chinaitop.videoPlay.service;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaitop.videoPlay.mapper.BaseAlarmMapper;
import com.chinaitop.videoPlay.model.BaseAlarm;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Objects;

/**
 * @author qingsong.han
 * @description: 由于ReceiveData接收数据类型有下滑线(_)返回前端接口为null,
 * 所以重新创建接口和实例.
 * @create 2023-10-20 17:41
 */
public interface BaseAlarmService extends IService<BaseAlarm> {
    IPage<BaseAlarm> getPageList(Integer pageNum, Integer pageSize, String alarmTypeName, String alarmTime) throws Exception;

    List<BaseAlarm> getOldPageList(Integer pageNum, Integer pageSize, String alarmTypeName, String alarmTime);

    @Service
    class BaseAlarmServiceImpl extends ServiceImpl<BaseAlarmMapper, BaseAlarm> implements BaseAlarmService {
        @Resource
        private BaseAlarmMapper baseAlarmMapper;

        @Override
        public IPage<BaseAlarm> getPageList(Integer pageNum, Integer pageSize, String alarmTypeName, String alarmTime) throws Exception {
            // 查询对象
            QueryWrapper<BaseAlarm> qw = new QueryWrapper<>();
            if (StringUtils.hasText(alarmTypeName)) {
                qw.like("alarm_type_name", alarmTypeName);
            }
            if (StringUtils.hasText(alarmTime)) {
                String startTime = String.format("%s %s", alarmTime, "00:00:00");
                String endTime = String.format("%s %s", alarmTime, "23:59:59");
                qw.between("alarm_time",
                        startTime,
                        endTime
                );
                /*qw.between("alarm_time",
                        new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").parse(startTime),
                        new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").parse(endTime)
                );*/
            }
            qw.orderByDesc("alarm_time");
            return baseAlarmMapper.selectPage(new Page<>(pageNum, pageSize), qw);
        }

        @Override
        public List<BaseAlarm> getOldPageList(Integer pageNum, Integer pageSize, String alarmTypeName, String alarmTime) {
            // 查询对象
            QueryWrapper<BaseAlarm> qw = new QueryWrapper<>();
            if (StringUtils.hasText(alarmTypeName)) {
                qw.like("alarm_type_name", alarmTypeName);
            }
            if (StringUtils.hasText(alarmTime)) {
                String startTime = String.format("%s %s", alarmTime, "00:00:00");
                String endTime = String.format("%s %s", alarmTime, "23:59:59");
                qw.between("alarm_time", startTime, endTime);
            }
            qw.orderByDesc("alarm_time");
            return baseAlarmMapper.selectList(qw);
        }
    }

}
